==> jc-1.4.0.tar.gz: soot/grimp/internal/GTableSwitchStmt.h <==
// public class soot.grimp.internal.GTableSwitchStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class c857089521721918 soot_grimp_internal_GTableSwitchStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class dd962d8ef5594c41 soot_jimple_internal_JTableSwitchStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JTableSwitchStmt

#include "soot/jimple/internal/JTableSwitchStmt.h"

#ifndef _JC_soot_grimp_internal_GTableSwitchStmt_H_
#define _JC_soot_grimp_internal_GTableSwitchStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_refs	_jc_soot_grimp_internal_GTableSwitchStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs	_jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$refs	_jc_soot_grimp_internal_GTableSwitchStmt$refs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$nonrefs	_jc_soot_grimp_internal_GTableSwitchStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$object	_jc_soot_grimp_internal_GTableSwitchStmt$object;

typedef const struct _jc_soot_grimp_internal_GTableSwitchStmt$vmethods	_jc_soot_grimp_internal_GTableSwitchStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GTableSwitchStmt$vtable	_jc_soot_grimp_internal_GTableSwitchStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GTableSwitchStmt$vtype	_jc_soot_grimp_internal_GTableSwitchStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GTableSwitchStmt$method$_init$39f9cbd245364c16(_jc_env *, struct _jc_soot_grimp_internal_GTableSwitchStmt$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GTableSwitchStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GTableSwitchStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GTableSwitchStmt$method_info$clone$b75f2713d6705f70;

// Static methods
extern _jc_object_array *_jc_soot_grimp_internal_GTableSwitchStmt$method$getTargetBoxesArray$2b80c07c5813e00c(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_grimp_internal_GTableSwitchStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GTableSwitchStmt$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GTableSwitchStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JTableSwitchStmt$vmethods	soot_jimple_internal_JTableSwitchStmt;
	_jc_soot_grimp_internal_GTableSwitchStmt$vmethods	soot_grimp_internal_GTableSwitchStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GTableSwitchStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GTableSwitchStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GTableSwitchStmt$refs {
    _jc_soot_grimp_internal_GTableSwitchStmt$sub_refs	soot_grimp_internal_GTableSwitchStmt;
    _jc_soot_jimple_internal_JTableSwitchStmt$sub_refs	soot_jimple_internal_JTableSwitchStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GTableSwitchStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JTableSwitchStmt$sub_nonrefs	soot_jimple_internal_JTableSwitchStmt;
    _jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs	soot_grimp_internal_GTableSwitchStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GTableSwitchStmt$object {
	_jc_soot_grimp_internal_GTableSwitchStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GTableSwitchStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GTableSwitchStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GTableSwitchStmt$vtype _jc_soot_grimp_internal_GTableSwitchStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GTableSwitchStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GTableSwitchStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GTableSwitchStmt_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GTableSwitchStmt.h <==
// public class soot.grimp.internal.GTableSwitchStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class c857089521721918 soot_grimp_internal_GTableSwitchStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class dd962d8ef5594c41 soot_jimple_internal_JTableSwitchStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JTableSwitchStmt

#include "soot/jimple/internal/JTableSwitchStmt.h"

#ifndef _JC_soot_grimp_internal_GTableSwitchStmt_H_
#define _JC_soot_grimp_internal_GTableSwitchStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_refs	_jc_soot_grimp_internal_GTableSwitchStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs	_jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$refs	_jc_soot_grimp_internal_GTableSwitchStmt$refs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$nonrefs	_jc_soot_grimp_internal_GTableSwitchStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GTableSwitchStmt$object	_jc_soot_grimp_internal_GTableSwitchStmt$object;

typedef const struct _jc_soot_grimp_internal_GTableSwitchStmt$vmethods	_jc_soot_grimp_internal_GTableSwitchStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GTableSwitchStmt$vtable	_jc_soot_grimp_internal_GTableSwitchStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GTableSwitchStmt$vtype	_jc_soot_grimp_internal_GTableSwitchStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GTableSwitchStmt$method$_init$39f9cbd245364c16(_jc_env *, struct _jc_soot_grimp_internal_GTableSwitchStmt$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GTableSwitchStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GTableSwitchStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GTableSwitchStmt$method_info$clone$b75f2713d6705f70;

// Static methods
extern _jc_object_array *_jc_soot_grimp_internal_GTableSwitchStmt$method$getTargetBoxesArray$2b80c07c5813e00c(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_grimp_internal_GTableSwitchStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GTableSwitchStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GTableSwitchStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JTableSwitchStmt$vmethods	soot_jimple_internal_JTableSwitchStmt;
	_jc_soot_grimp_internal_GTableSwitchStmt$vmethods	soot_grimp_internal_GTableSwitchStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GTableSwitchStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GTableSwitchStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GTableSwitchStmt$refs {
    _jc_soot_grimp_internal_GTableSwitchStmt$sub_refs	soot_grimp_internal_GTableSwitchStmt;
    _jc_soot_jimple_internal_JTableSwitchStmt$sub_refs	soot_jimple_internal_JTableSwitchStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GTableSwitchStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JTableSwitchStmt$sub_nonrefs	soot_jimple_internal_JTableSwitchStmt;
    _jc_soot_grimp_internal_GTableSwitchStmt$sub_nonrefs	soot_grimp_internal_GTableSwitchStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GTableSwitchStmt$object {
	_jc_soot_grimp_internal_GTableSwitchStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GTableSwitchStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GTableSwitchStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GTableSwitchStmt$vtype _jc_soot_grimp_internal_GTableSwitchStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GTableSwitchStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GTableSwitchStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GTableSwitchStmt_H_ */
